@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2021  The Software Heritage developers
+# Copyright (C) 2015-2022  The Software Heritage developers
 # See the AUTHORS file at the top-level directory of this distribution
 # License: GNU General Public License version 3, or any later version
 # See top-level LICENSE file for more information
@@ -14,6 +14,19 @@ import magic
 
 from . import utils
 
+MIMETYPE_TO_ARCHIVE_FORMAT = {
+    "application/x-compress": "tar.Z|x",
+    "application/x-tar": "tar",
+    "application/x-bzip2": "bztar",
+    "application/gzip": "gztar",
+    "application/x-gzip": "gztar",
+    "application/x-lzip": "tar.lz",
+    "application/zip": "zip",
+    "application/java-archive": "jar",
+    "application/zstd": "tar.zst",
+    "application/x-zstd": "tar.zst",
+}
+
 
 def _unpack_tar(tarpath: str, extract_dir: str) -> str:
     """Unpack tarballs unsupported by the standard python library. Examples
@@ -117,19 +130,6 @@ def register_new_archive_formats():
         shutil.register_unpack_format(name, extensions, function)
 
 
-_mime_to_archive_format = {
-    "application/x-compress": "tar.Z|x",
-    "application/x-tar": "tar",
-    "application/x-bzip2": "bztar",
-    "application/gzip": "gztar",
-    "application/x-lzip": "tar.lz",
-    "application/zip": "zip",
-    "application/java-archive": "jar",
-    "application/zstd": "tar.zst",
-    "application/x-zstd": "tar.zst",
-}
-
-
 def uncompress(tarpath: str, dest: str):
     """Uncompress tarpath to dest folder if tarball is supported.
 
@@ -157,7 +157,7 @@ def uncompress(tarpath: str, dest: str):
         if format is None:
             m = magic.Magic(mime=True)
             mime = m.from_file(tarpath)
-            format = _mime_to_archive_format.get(mime)
+            format = MIMETYPE_TO_ARCHIVE_FORMAT.get(mime)
         shutil.unpack_archive(tarpath, extract_dir=dest, format=format)
     except shutil.ReadError as e:
         raise ValueError(f"Problem during unpacking {tarpath}. Reason: {e}")
@@ -166,6 +166,13 @@ def uncompress(tarpath: str, dest: str):
             _unpack_zip(tarpath, dest)
         else:
             raise
+    except NotADirectoryError:
+        if format and "tar" in format:
+            # some old tarballs might fail to be unpacked by shutil.unpack_archive,
+            # fallback using the tar command as last resort
+            _unpack_tar(tarpath, dest)
+        else:
+            raise
 
     normalize_permissions(dest)
 
@@ -179,8 +186,11 @@ def normalize_permissions(path: str):
     Args:
       path: the path under which permissions should be normalized
     """
-    for dirpath, _, fnames in os.walk(path):
-        os.chmod(dirpath, 0o0755)
+    os.chmod(path, 0o0755)
+    for dirpath, dnames, fnames in os.walk(path):
+        for dname in dnames:
+            dpath = os.path.join(dirpath, dname)
+            os.chmod(dpath, 0o0755)
         for fname in fnames:
             fpath = os.path.join(dirpath, fname)
             if not os.path.islink(fpath):
